#[no_mangle]
pub unsafe extern "C" fn atp_deserialize_thread_info(
    in_bytes: *mut u8
) -> *mut atp_thread_info
From a byte buffer, return a RtPriorityThreadInfo, with a C API.

This call is useful on Linux desktop only, when the process is sandboxed and cannot promote itself directly.

Arguments

A byte buffer containing a serializezd RtPriorityThreadInfo.

Safety

This function is safe only and only if pointer is at least ATP_THREAD_INFO_SIZE bytes long.