#[no_mangle]
pub extern "C" fn atp_get_current_thread_info(
    
) -> *mut atp_thread_info
Get the calling threads’ information, to promote it from another process or thread, with a C API.

This is intended to call on the thread that will end up being promoted to real time priority, but that cannot do it itself (probably because of sandboxing reasons).

After use, it MUST be freed by calling atp_free_thread_info.

Return value

A pointer to a struct that can be serialized and deserialized, and that can be passed to atp_promote_thread_to_real_time, even from another process.