Function audio_thread_priority::atp_serialize_thread_info
source · #[no_mangle]
pub unsafe extern "C" fn atp_serialize_thread_info(
thread_info: *mut atp_thread_info,
bytes: *mut c_void
)Expand description
Return a byte buffer containing serialized information about a thread, to promote it to real-time from elsewhere, with a C API.
bytes MUST be std::mem::size_of<RtPriorityThreadInfo>() bytes long.
This is exposed in the C API as ATP_THREAD_INFO_SIZE.
This call is useful on Linux desktop only, when the process is sandboxed, cannot promote itself
directly, and the atp_thread_info struct must be passed via IPC.