get_current_thread_info

Function get_current_thread_info 

pub fn get_current_thread_info() -> Result<RtPriorityThreadInfo, AudioThreadPriorityError>
Get the calling thread’s information, to be able to promote it to real-time from somewhere else, later.

This is useful on Linux only, to promote a thread from another process or thread when the thread to promote cannot do so itself (for example because it is sandboxed).

Return value

Ok in case of success, with an opaque structure containing relevant info for the platform, Err otherwise.