pub fn thread_info_deserialize(bytes: [u8; 24]) -> RtPriorityThreadInfo
From a byte buffer, return a RtPriorityThreadInfo.

This call is useful on Linux desktop only, when the process is sandboxed and cannot promote itself directly.

Arguments

A byte buffer containing a serializezd RtPriorityThreadInfo.