[−][src]Function audio_thread_priority::atp_deserialize_thread_info
#[no_mangle]pub extern "C" fn atp_deserialize_thread_info(
in_bytes: *mut uint8_t
) -> *mut atp_thread_info
From a byte buffer, return a RtPriorityThreadInfo, with a C API.
This call is useful on Linux desktop only, when the process is sandboxed and cannot promote itself directly.
Arguments
A byte buffer containing a serializezd RtPriorityThreadInfo.