pub fn get_current_thread_info() -> Result<RtPriorityThreadInfo, AudioThreadPriorityError>Expand description
Get the calling thread’s information, to be able to promote it to real-time from somewhere else, later.
This call is useful on Linux desktop only, when the process is sandboxed and cannot promote itself directly.
Return value
Ok in case of success, with an opaque structure containing relevant info for the platform, Err otherwise.