[−][src]Function audio_thread_priority::thread_info_serialize
pub fn thread_info_serialize(thread_info: RtPriorityThreadInfo) -> [u8; 32]
Return a byte buffer containing serialized information about a thread, to promote it to real-time from elsewhere.
This call is useful on Linux desktop only, when the process is sandboxed and cannot promote itself directly.